#
# spec file for package libxcrypt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%define major 1
%define libname %mklibname xcrypt %{major}
%define devellibname %mklibname xcrypt -d
%define staticlibname %mklibname xcrypt -d -s


Name:           libxcrypt
Version:        4.4.33
Release:        %mkrel 3
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
URL:            https://github.com/besser82/%{name}
Source0:        https://github.com/besser82/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

# Patch 0000 - 2999: Backported patches from upstream.
Patch0000:      %{url}/commit/9d5e7b7307f2.patch#/%{name}-4.4.33-yescrypt_platform_cast_performance.patch
Patch0001:      %{url}/commit/59823543d095.patch#/%{name}-4.4.33-SHA512_Maj_optimization.patch

# Patch 3000 - 5999: Backported patches from pull requests.

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
# (tmb) temp force new gcc
BuildRequires:  gcc >= 10.1.0-1
# (tmb) force latest binutils
BuildRequires:  binutils >= 1:2.34-10


%description
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{libname}
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          System/Libraries
Conflicts:      glibc < 6:2.28-2

%description -n %{libname}
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{devellibname}
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Conflicts:      glibc-devel < 6:2.28-2
Provides:       %{name}-devel = %{version}-%{release}
Provides:       xcrypt-devel = %{version}-%{release}

%description  -n %{devellibname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package  -n %{staticlibname}
Summary:        Static library for -static linking with %{name}
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Requires:       %{devellibname} = %{version}
Requires:       glibc-static-devel
Conflicts:      glibc-static-devel < 6:2.28-2

%description -n %{staticlibname}
This package contains the libxcrypt static libraries for -static
linking.  You don't need this, unless you link statically, which
is highly discouraged.


%prep
%autosetup -p 1

%build
autoreconf -fiv
# Disable arc4random_buf on purpose, so we are able
# to run test/getrandom-fallback from testsuite.
%configure           \
  ac_cv_func_arc4random_buf=no \
  --disable-silent-rules \
  --enable-shared        \
  --enable-static        \
  --enable-obsolete-api  \
  --enable-hashes=all    \
  --with-pkgconfigdir=%{_libdir}/pkgconfig
%make_build
%make_build test-programs

%install
%make_install

find %{buildroot}%{_libdir} -name '*.la' -print -delete

%check
%make_build check || \
  {
    rc=$?;
    echo "-----BEGIN TESTLOG-----";
    cat test-suite.log;
    echo "-----END TESTLOG-----";
    exit $rc;
  }

%files -n %{libname}
%license COPYING.LIB LICENSING
%doc AUTHORS NEWS README.md THANKS
%{_libdir}/libcrypt.so.%{major}{,.*}
%{_libdir}/libowcrypt.so.%{major}

%files -n %{devellibname}
%doc TODO.md
%{_includedir}/crypt.h
%{_includedir}/xcrypt.h
%{_libdir}/libcrypt.so
%{_libdir}/libowcrypt.so
%{_libdir}/libxcrypt.so
%{_libdir}/pkgconfig/libcrypt.pc
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/crypt.3.*
%{_mandir}/man3/crypt_checksalt.3.*
%{_mandir}/man3/crypt_gensalt.3.*
%{_mandir}/man3/crypt_gensalt_ra.3.*
%{_mandir}/man3/crypt_gensalt_rn.3.*
%{_mandir}/man3/crypt_preferred_method.3.*
%{_mandir}/man3/crypt_r.3.*
%{_mandir}/man3/crypt_ra.3.*
%{_mandir}/man3/crypt_rn.3.*
%{_mandir}/man5/crypt.5.*

%files -n %{staticlibname}
%{_libdir}/libcrypt.a
%{_libdir}/libowcrypt.a
%{_libdir}/libxcrypt.a


%changelog
* Wed Dec 14 2022 tv <tv> 4.4.33-3.mga9
+ Revision: 1922064
- Add upstream patch to improve performance on SHA512 computation

* Wed Nov 30 2022 tv <tv> 4.4.33-2.mga9
+ Revision: 1913340
- Add upstream patch to improve performance on some type-cast operations

* Tue Nov 22 2022 luigiwalser <luigiwalser> 4.4.33-1.mga9
+ Revision: 1910037
- 4.4.33

* Wed Nov 16 2022 tv <tv> 4.4.31-1.mga9
+ Revision: 1907883
- 4.4.31

* Wed Nov 09 2022 luigiwalser <luigiwalser> 4.4.30-2.mga9
+ Revision: 1904939
- add upstream patches via fedora for various fixes
- add test suite fix from fedora

* Sat Nov 05 2022 tv <tv> 4.4.30-1.mga9
+ Revision: 1903695
- 4.4.30

* Tue Aug 30 2022 tv <tv> 4.4.28-4.mga9
+ Revision: 1882050
- Rebuilt for arc4random_buf in glibc 2.36 (or later)

* Sat Mar 19 2022 umeabot <umeabot> 4.4.28-3.mga9
+ Revision: 1799923
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tmb <tmb> 4.4.28-2.mga9
+ Revision: 1779479
- rebuild with glibc 2.35-3

* Fri Feb 04 2022 tv <tv> 4.4.28-1.mga9
+ Revision: 1771399
- 4.4.28

* Sat Dec 18 2021 tv <tv> 4.4.27-1.mga9
+ Revision: 1762437
- 4.4.27

* Tue Sep 28 2021 tmb <tmb> 4.4.26-2.mga9
+ Revision: 1746823
- rebuild with glibc 2.34

* Tue Sep 21 2021 luigiwalser <luigiwalser> 4.4.26-1.mga9
+ Revision: 1746137
- 4.4.26

* Thu Aug 12 2021 luigiwalser <luigiwalser> 4.4.25-1.mga9
+ Revision: 1741141
- 4.4.25

* Thu Aug 05 2021 tv <tv> 4.4.24-1.mga9
+ Revision: 1739528
- 4.4.24

* Mon Jun 21 2021 tv <tv> 4.4.23-1.mga9
+ Revision: 1731566
- 4.4.23

* Thu Jun 17 2021 tv <tv> 4.4.22-2.mga9
+ Revision: 1730976
- Add patches to fix issues with type conversion in the DES code

* Mon Jun 07 2021 tv <tv> 4.4.22-1.mga9
+ Revision: 1730056
- 4.4.22
- Add a patch to fix o_size calculation for gensalt_yescrypt_rn

* Fri May 07 2021 tv <tv> 4.4.20-1.mga9
+ Revision: 1722239
- 4.4.20

* Sun Apr 11 2021 tv <tv> 4.4.19-1.mga9
+ Revision: 1714746
- 4.4.19

* Sat Feb 27 2021 luigiwalser <luigiwalser> 4.4.18-1.mga9
+ Revision: 1693021
- 4.4.18

* Sun Aug 23 2020 tv <tv> 4.4.17-1.mga8
+ Revision: 1618102
- 4.4.17

* Thu May 07 2020 tmb <tmb> 4.4.16-4.mga8
+ Revision: 1581510
- rebuild with gcc-10.1.0 final

* Mon May 04 2020 tmb <tmb> 4.4.16-2.mga8
+ Revision: 1579653
- rebuild with gcc 10.1

* Wed Apr 08 2020 luigiwalser <luigiwalser> 4.4.16-1.mga8
+ Revision: 1565494
- 4.4.16

* Thu Mar 05 2020 luigiwalser <luigiwalser> 4.4.15-1.mga8
+ Revision: 1553895
- 4.4.15

* Tue Feb 25 2020 luigiwalser <luigiwalser> 4.4.14-1.mga8
+ Revision: 1550288
- 4.4.14

* Thu Feb 20 2020 umeabot <umeabot> 4.4.12-2.mga8
+ Revision: 1546344
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 luigiwalser <luigiwalser> 4.4.12-1.mga8
+ Revision: 1486397
- 4.4.12
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jan 02 2020 luigiwalser <luigiwalser> 4.4.10-1.mga8
+ Revision: 1475416
- 4.4.10

* Tue Aug 13 2019 tmb <tmb> 4.4.6-2.mga8
+ Revision: 1429146
- rebuild with gcc 9.2

* Mon May 13 2019 luigiwalser <luigiwalser> 4.4.6-1.mga7
+ Revision: 1397522
- 4.4.6

* Fri Mar 15 2019 tmb <tmb> 4.4.4-1.mga7
+ Revision: 1377597
- update to 4.4.4

* Thu Feb 07 2019 tmb <tmb> 4.4.3-1.mga7
+ Revision: 1364054
- update to 4.4.3

* Sun Dec 30 2018 luigiwalser <luigiwalser> 4.4.2-1.mga7
+ Revision: 1346914
- 4.4.2

* Mon Dec 03 2018 tmb <tmb> 4.4.0-1.mga7
+ Revision: 1338066
- update to 4.4.0

* Thu Nov 08 2018 tv <tv> 4.2.3-2.mga7
+ Revision: 1328853
- fix broken symlink doc in devel pkg

* Wed Nov 07 2018 tmb <tmb> 4.2.3-1.mga7
+ Revision: 1328794
- update to 4.2.3

* Thu Oct 11 2018 tmb <tmb> 4.2.1-1.mga7
+ Revision: 1319636
- update to 4.2.1

* Mon Sep 03 2018 daviddavid <daviddavid> 4.1.2-2.mga7
+ Revision: 1256347
- fix dangling link (mga#23515)

* Wed Aug 29 2018 tmb <tmb> 4.1.2-1.mga7
+ Revision: 1255525
- update filelist for added manpages
- update to 4.1.2

* Sat Aug 18 2018 wally <wally> 4.1.1-3.mga7
+ Revision: 1252492
- add more provides to devel pkg

* Wed Aug 08 2018 tmb <tmb> 4.1.1-2.mga7
+ Revision: 1250235
- conflict crypt enabled glibc packages

* Wed Aug 08 2018 tmb <tmb> 4.1.1-1.mga7
+ Revision: 1249772
- fix build
- fix groups
- adapt to mageia
- update to 4.1.1
- Import from OpenSUSE

